==> magic3_1.7.0_src.tar.gz: magic3/scripts/fckeditor2.6/editor/plugins/FileBrowser_Thumbnail/lang/ja.js <==
/*
 * FCKeditor - The text editor for internet
 * Copyright (C) 2003-2006 Frederico Caldeira Knabben
 * 
 * Licensed under the terms of the GNU Lesser General Public License:
 * 		http://www.opensource.org/licenses/lgpl-license.php
 * 
 * For further information visit:
 * 		http://www.fckeditor.net/
 * 
 * "Support Open Source software. What about a donation today?"
 * 
 * File Name: ja.js
 * 	SimpleFileBrowser Japanese language file.
 * 
 * File Authors:
 * 		Akira Taniguchi (akira@behappy.2-d.jp)
 */
FCKLang.Browser						= 'ファイルブラウザー' ;

FCKLang.BrowserResourceType			= 'リソースのタイプ' ;
FCKLang.BrowserResourceTypeFile		= 'ファイル' ;
FCKLang.BrowserResourceTypeImage	= 'イメージ' ;
FCKLang.BrowserResourceTypeFlash	= 'Flash' ;
FCKLang.BrowserResourceTypeMedia	= 'メディア' ;

FCKLang.BrowserNameExists			= 'すでに存在しています' ;
FCKLang.BrowserNoPermission			= 'ファイル・フォルダを更新する権限がありません' ;
FCKLang.BrowserDisableName			= 'ファイル名が不正です' ;
FCKLang.BrowserDisableChars			= 'ファイル名には以下の文字は使えません\n\\/:"*?<>|' ;

FCKLang.BrowserFileSize				= 'サイズ' ;
FCKLang.BrowserFileDelete			= 'ファイルの削除' ;
FCKLang.BrowserFileDeleteConfirm	= '本当に "%1" を削除しますか?' ;
FCKLang.BrowserFileDeleteError		= 'ファイルを削除できませんでした' ;

FCKLang.BrowserFileRename			= 'ファイル名の変更' ;
FCKLang.BrowserFileRenameMessage	= '"%1" の新しいファイル名を入力してください' ;
FCKLang.BrowserFileRenameExtChange	= '拡張子は変更できません' ;
FCKLang.BrowserFileRenameError		= 'ファイルをリネームできませんでした' ;

FCKLang.BrowserFolderDelete			= 'フォルダの削除' ;
FCKLang.BrowserFolderDeleteConfirm	= '本当に "%1" 以下の全てを削除しますか?' ;
FCKLang.BrowserFolderDeleteError	= 'フォルダを削除できませんでした' ;

FCKLang.BrowserFolderRename			= 'フォルダ名の変更' ;
FCKLang.BrowserFolderRenameMessage	= '"%1" の新しいフォルダ名を入力してください' ;
FCKLang.BrowserFolderRenameError	= 'フォルダをリネームできませんでした' ;

FCKLang.BrowserNewFolderMessage		= '新しいフォルダを作成' ;
FCKLang.BrowserNewFolderNameMessage	= '新しいフォルダ名を入力してください' ;
FCKLang.BrowserNewFolderError		= 'フォルダを作成できませんでした' ;

FCKLang.BrowserUpload				= 'アップロード' ;
FCKLang.BrowserUploadMessage		= 'このフォルダに新しいファイルをアップロード' ;
FCKLang.BrowserUploadMessageWait	= 'このフォルダに新しいファイルをアップロード (アップロード中...)' ;
FCKLang.BrowserUploadNoFile			= 'ファイルを選択してください' ;
FCKLang.BrowserUploadAvailable		= '同じ名前のファイルが在るため、以下のファイル名でアップロードしました\n\n"%1"' ;
FCKLang.BrowserUploadNoParam		= '不正なパラメーターです' ;
FCKLang.BrowserUploadTooBig			= '%1KB を超えるファイルはアップロードできません' ;
FCKLang.BrowserUploadExtNothing		= '拡張子を指定してください' ;
FCKLang.BrowserUploadExtDisable		= 'この拡張子のファイルはアップロードできません' ;
FCKLang.BrowserUploadSizeError		= '以下のフォルダーの使用量を算出できません\n\n"%1"' ;
FCKLang.BrowserUploadQuotaGlobal	= 'アップロード領域が %1MB を超えるためアップロードできません' ;
FCKLang.BrowserUploadQuotaType		= 'リソース領域が %1MB を超えるためアップロードできません' ;
FCKLang.BrowserUploadAvailableMany	= '同じファイル名が多すぎます' ;
FCKLang.BrowserUploadNotUploaded	= '不正なアップロード処理です' ;
FCKLang.BrowserUploadInvalid		= 'ファイルをアップロードできませんでした' ;

==> magic3_1.8.0_b11_src.tar.gz: magic3/scripts/fckeditor2.6/editor/plugins/FileBrowser_Thumbnail/lang/ja.js <==
/*
 * FCKeditor - The text editor for internet
 * Copyright (C) 2003-2006 Frederico Caldeira Knabben
 * 
 * Licensed under the terms of the GNU Lesser General Public License:
 * 		http://www.opensource.org/licenses/lgpl-license.php
 * 
 * For further information visit:
 * 		http://www.fckeditor.net/
 * 
 * "Support Open Source software. What about a donation today?"
 * 
 * File Name: ja.js
 * 	SimpleFileBrowser Japanese language file.
 * 
 * File Authors:
 * 		Akira Taniguchi (akira@behappy.2-d.jp)
 */
FCKLang.Browser						= 'ファイルブラウザー' ;

FCKLang.BrowserResourceType			= 'リソースのタイプ' ;
FCKLang.BrowserResourceTypeFile		= 'ドキュメント' ;
FCKLang.BrowserResourceTypeImage	= '画像' ;
FCKLang.BrowserResourceTypeFlash	= 'Flash' ;
FCKLang.BrowserResourceTypeMedia	= '動画・音声' ;

FCKLang.BrowserNameExists			= 'すでに存在しています' ;
FCKLang.BrowserNoPermission			= 'ファイル・フォルダを更新する権限がありません' ;
FCKLang.BrowserDisableName			= 'ファイル名が不正です' ;
FCKLang.BrowserDisableChars			= 'ファイル名には以下の文字は使えません\n\\/:"*?<>|' ;

FCKLang.BrowserFileSize				= 'サイズ' ;
FCKLang.BrowserFileDelete			= 'ファイルの削除' ;
FCKLang.BrowserFileDeleteConfirm	= '本当に "%1" を削除しますか?' ;
FCKLang.BrowserFileDeleteError		= 'ファイルを削除できませんでした' ;

FCKLang.BrowserFileRename			= 'ファイル名の変更' ;
FCKLang.BrowserFileRenameMessage	= '"%1" の新しいファイル名を入力してください' ;
FCKLang.BrowserFileRenameExtChange	= '拡張子は変更できません' ;
FCKLang.BrowserFileRenameError		= 'ファイルをリネームできませんでした' ;

FCKLang.BrowserFolderDelete			= 'フォルダの削除' ;
FCKLang.BrowserFolderDeleteConfirm	= '本当に "%1" 以下の全てを削除しますか?' ;
FCKLang.BrowserFolderDeleteError	= 'フォルダを削除できませんでした' ;

FCKLang.BrowserFolderRename			= 'フォルダ名の変更' ;
FCKLang.BrowserFolderRenameMessage	= '"%1" の新しいフォルダ名を入力してください' ;
FCKLang.BrowserFolderRenameError	= 'フォルダをリネームできませんでした' ;

FCKLang.BrowserNewFolderMessage		= '新しいフォルダを作成' ;
FCKLang.BrowserNewFolderNameMessage	= '新しいフォルダ名を入力してください' ;
FCKLang.BrowserNewFolderError		= 'フォルダを作成できませんでした' ;

FCKLang.BrowserUpload				= 'アップロード' ;
FCKLang.BrowserUploadMessage		= 'このフォルダに新しいファイルをアップロード' ;
FCKLang.BrowserUploadMessageWait	= 'このフォルダに新しいファイルをアップロード (アップロード中...)' ;
FCKLang.BrowserUploadNoFile			= 'ファイルを選択してください' ;
FCKLang.BrowserUploadAvailable		= '同じ名前のファイルが在るため、以下のファイル名でアップロードしました\n\n"%1"' ;
FCKLang.BrowserUploadNoParam		= '不正なパラメーターです' ;
FCKLang.BrowserUploadTooBig			= '%1KB を超えるファイルはアップロードできません' ;
FCKLang.BrowserUploadExtNothing		= '拡張子を指定してください' ;
FCKLang.BrowserUploadExtDisable		= 'この拡張子のファイルはアップロードできません' ;
FCKLang.BrowserUploadSizeError		= '以下のフォルダーの使用量を算出できません\n\n"%1"' ;
FCKLang.BrowserUploadQuotaGlobal	= 'アップロード領域が %1MB を超えるためアップロードできません' ;
FCKLang.BrowserUploadQuotaType		= 'リソース領域が %1MB を超えるためアップロードできません' ;
FCKLang.BrowserUploadAvailableMany	= '同じファイル名が多すぎます' ;
FCKLang.BrowserUploadNotUploaded	= '不正なアップロード処理です' ;
FCKLang.BrowserUploadInvalid		= 'ファイルをアップロードできませんでした' ;
